"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadVite = exports.resolveAlias = exports.resolveFinalConfig = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const resolveFinalConfig = (config) => {
    const finalConfig = {
        vscode: true,
        alias: [],
    };
    if (config) {
        finalConfig.vscode = config.vscode === undefined ? true : config.vscode;
        finalConfig.alias = config.alias || [];
    }
    return finalConfig;
};
exports.resolveFinalConfig = resolveFinalConfig;
const resolveAlias = (alias, dir, importDec) => {
    for (const { find, replacement } of alias) {
        if (importDec.source.value.startsWith(find)) {
            const replaced = importDec.source.value.replace(find, replacement);
            if (path_1.default.isAbsolute(replaced)) {
                return importDec.source.value.replace(find, replacement);
            }
            else {
                return path_1.default.resolve(dir, replaced);
            }
        }
    }
    return path_1.default.resolve(dir, importDec.source.value);
};
exports.resolveAlias = resolveAlias;
const loadVite = async () => {
    try {
        const config = fs_1.default.readFileSync((path_1.default.resolve(), 'vite.config.ts'));
        const fallbackPaths = require.resolve.paths?.('vite') || [];
        const resolved = require.resolve('vite', {
            paths: [...fallbackPaths],
        });
        // eslint-disable-next-line @typescript-eslint/no-var-requires
        const vite = require(resolved);
        const resolvedConfig = await vite.resolveConfig(config, 'serve');
        return resolvedConfig.resolve.alias
            ? resolvedConfig.resolve.alias.filter((alias) => typeof alias.find === 'string')
            : resolvedConfig.resolve.alias;
    }
    catch (e) {
        // Not founcd vite dependency.
        return;
    }
};
exports.loadVite = loadVite;
