"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeHtml = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const writeHtml = (diagram) => {
    const outputFilePath = path_1.default.resolve(path_1.default.resolve(), './stats.html');
    (0, fs_1.writeFileSync)(outputFilePath, makeHtml(diagram));
    console.log(chalk_1.default.green(`Success. ${outputFilePath}`));
    return;
};
exports.writeHtml = writeHtml;
const getDiagramJson = (diagram) => {
    return `const diagram =${JSON.stringify(diagram)}`;
};
const makeHtml = (diagram) => {
    const resolveFilePath = (filaPath) => path_1.default.resolve(__dirname, filaPath);
    return `<!DOCTYPE html>
<html>
  <head>
    <meta charset="UTF-8"/>
    <meta name="viewport" content="width=device-width, initial-scale=1"/>
    <title></title>
    <link href="${resolveFilePath('../dist/vendor/prism.css')}" rel="stylesheet" />
    <script>
    ${getDiagramJson(diagram)}
    </script>
    <style>
    body {
      font-family:"ヒラギノ角ゴ Pro W3", "Hiragino Kaku Gothic Pro", "メイリオ", Meiryo, Osaka, "ＭＳ Ｐゴシック", "MS PGothic", sans-serif;
      color: white !important;
      font-size: 11px;
      background: #01060B;
    }
    .bi.bi-diagram {      
      background-color: #01060B !important;
      overflow: scroll !important;
      border: none !important;
      box-shadow: none !important;
    }
    a {
      padding: 4px;
      cursor: pointer;
    }
    a + a {
      margin-left: 4px;
    }
    a,
    a:visited {
      color: white !important;
    }
    a:hover {
      opacity: .7;
    }
    .drawer { 
      height: 100%;
      background: white;
      position: fixed;
      top: 0;
      right: 0;
      width: 600px;
      z-index: 200;
      box-shadow: 1px 0px 7px rgba(0,0,0,0.5); 
      transform: translateX(100%);
      transition: transform 0.3s ease-out;
    }
    .drawer.open {
      transform: translateX(0);
    }
    .line-highlight {
      background: linear-gradient(to right, hsla(124, 120%, 50%,.15) 100%, hsla(24, 20%, 50%,0)) !important;
    }
    div.code-toolbar > .toolbar {
      top: -4px;
    }
    </style>
  </head>
  <body>
    <div id="root" />
    <script src="${resolveFilePath('../dist/viewer.js')}"></script>
  </body>
</html>`;
};
